@@ -3,7 +3,9 @@
 __name__ = "ontor"
 __author__ = "Felix Ocker"
 __author_email__ = "felix.ocker@googlemail.com"
-__version__ = "0.4.8"
+__version__ = "0.4.11"
 __url__ = "https://github.com/felixocker/ontor"
-__download_url__ = "https://github.com/felixocker/ontor/archive/refs/tags/v" + __version__ + ".tar.gz"
+__download_url__ = (
+    "https://github.com/felixocker/ontor/archive/refs/tags/v" + __version__ + ".tar.gz"
+)
 __keywords__ = ["ontology", "owl", "python", "knowledge graph"]
